@@ -1135,10 +1135,15 @@ def _lstrip_lines(text: str) -> str:
     return "\n".join([line.lstrip() for line in text.splitlines()])
 
 
-def _detail_align(lines: list[str], align: str, maxwidth: int = 150) -> str:
+# TODO: maxwidth should be a parameter that can be configured externally
+def _align(text: str, align: str = "<", maxwidth: int = 100) -> str:
     r"""
     Align ``&`` and ``\\`` of all lines that contain those alignment characters.
 
+    :warning:
+        Assumes that the first line contains ``\begin{...}[...]{...}`` and that the last line
+        contains ``\end{...}``. As this function is internal there is no assertion on this.
+
     :param text: Text.
     :param align: Alignment of columns (``"<"``, ``">"`` or ``"^"``).
     :param maxwidth:
@@ -1148,15 +1153,15 @@ def _detail_align(lines: list[str], align: str, maxwidth: int = 150) -> str:
     :return: Aligned text.
     """
 
-    lines = [line.strip() for line in lines]
+    lines = [line.strip() for line in text.strip().splitlines()]
     width = []
 
-    if len(lines) <= 1:
-        return lines
+    if len(lines) <= 3:
+        return "\n".join(lines)
 
-    for i, line in enumerate(lines):
+    for i in range(1, len(lines) - 1):
         # split at & and \\, and strip all spaces around
-        line = re.split(r"((?<!\\)&)", line)
+        line = re.split(r"((?<!\\)&)", lines[i])
         line = line[:-1] + re.split(r"((?<!\\)\\\\)", line[-1])
         line = list(filter(None, [i.strip() for i in line]))
         if line[0] == "&":
@@ -1173,50 +1178,26 @@ def _detail_align(lines: list[str], align: str, maxwidth: int = 150) -> str:
                     width[j] = max(width[j], len(line[j]))
 
     # all lines start with &: remove leading spaces
-    if all([line[0] == "" for line in lines]):
-        lines = [line[1:] for line in lines]
+    if all([lines[i][0] == "" for i in range(1, len(lines) - 1)]):
         width = width[1:]
+        for i in range(1, len(lines) - 1):
+            lines[i] = lines[i][1:]
 
     if sum(width) < maxwidth:
         fmt = " ".join("{" + str(i) + ":" + align + str(w) + "}" for i, w in enumerate(width))
     else:
         fmt = " ".join("{" + str(i) + "}" for i in range(len(width)))
 
-    for i, line in enumerate(lines):
-        if "&" in line:
-            lines[i] = fmt.format(*(line + [""] * (len(width) - len(line)))).rstrip()
+    for i in range(1, len(lines) - 1):
+        if "&" in lines[i]:
+            lines[i] = fmt.format(*(lines[i] + [""] * (len(width) - len(lines[i])))).rstrip()
         else:
-            lines[i] = " ".join(line)
+            lines[i] = " ".join(lines[i])
 
-    return lines
-
-
-def _align(
-    placeholders: list[Placeholder],
-    placeholders_comments: list[Placeholder],
-    align: str = "<",
-) -> tuple[str, list[Placeholder]]:
-    """
-    For all placeholders of environments:
-    -   Place ``\begin{...}[...]{...}`` and ``\\end{...}`` on own line.
-    -   Align ``&`` and ``\\`` of all lines that contain those alignment characters.
-
-    :warning: Assumes that each placeholder contains exactly one environment.
-    :warning: Assumes that all comments are replaced by placeholders.
-
-    :param placeholders: List of placeholders (changed in place).
-    :param placeholders_comments: List of placeholders that are comments.
-    """
-
-    for placeholder in placeholders:
-        content = placeholder.content.strip()
-        content = _begin_end_one_separate_line(content, placeholders_comments)
-        content = text_from_placeholders(content, placeholders_comments, keep_placeholders=True)
-        lines = content.strip().splitlines()
-        lines[1:-1] = _detail_align(lines[1:-1], align)
-        placeholder.content = "\n".join(lines)
+    return "\n".join(lines)
 
 
+@deprecated("Use ``indent`` instead.")
 def align(
     text: str,
     environment: str,
@@ -1234,28 +1215,7 @@ def align(
     :param base: Base for temporary placeholders.
     :return: Formatted text.
     """
-
-    text, placeholders_comments = text_to_placeholders(
-        text, [PlaceholderType.comment, PlaceholderType.inline_comment], base=base
-    )
-
-    indices = find_matching(
-        text,
-        r"\\begin{" + environment + r"}",
-        r"\\end{" + environment + r"}",
-        escape=False,
-        closing_match=1,
-        return_array=True,
-    )
-
-    text, placeholders = _apply_placeholders(
-        text, indices, base, environment.upper(), PlaceholderType.environment
-    )
-
-    _align(placeholders, placeholders_comments, align=align)
-    text = text_from_placeholders(text, placeholders)
-    text = text_from_placeholders(text, placeholders_comments)
-    return text
+    return indent(text, indent="")
 
 
 def _is_placeholder(text: str, placeholders: list[Placeholder]) -> list[bool]:
@@ -1361,11 +1321,11 @@ def indent(text: str, indent: str = "    ") -> str:
     if len(text) == 0:
         return text
 
-    # known limitation
+    # check for known limitation
     if re.match(r"(?<!\\)(\$)(?<!\\)(\$)", text):
         raise NotImplementedError("Panic: don't know to deal with double dollar signs")
 
-    # remove leading/trailing newlines, and trailing whitespace
+    # remove leading/trailing newlines, and trailing whitespace on each line
     text = _rstrip_lines(text.strip())
 
     # "noindent" blocks are kept exactly as they are
@@ -1392,18 +1352,14 @@ def indent(text: str, indent: str = "    ") -> str:
     for placeholder in placeholders_rcomment:
         placeholder.space_front = re.sub(r"\ +", r" ", placeholder.space_front)
 
+    # all comments are equal for the remainder of the implementation
     placeholders_comments = placeholders_comment + placeholders_rcomment
 
     # remove multiple newlines, duplicate spaces, and any leading whitespace
-    text = re.sub(r"(\n\n+)", r"\n\n", text)
     text = _lstrip_lines(text)
+    text = re.sub(r"(\n\n+)", r"\n\n", text)
     text = re.sub(r"(\ +)", r" ", text)
 
-    # format tables: aligns if possible
-    text, placeholders_table = text_to_placeholders(text, [PlaceholderType.tabular])
-    _align(placeholders_table, placeholders_comments)
-    text = text_from_placeholders(text, placeholders_table)
-
     # fold inline math
     text, placeholders_inline_math = text_to_placeholders(text, [PlaceholderType.inline_math])
     # inline math: always on one line
@@ -1420,14 +1376,21 @@ def indent(text: str, indent: str = "    ") -> str:
     text = _begin_end_one_separate_line(text, placeholders_comments)
     text = text_from_placeholders(text, placeholders_let)
 
+    # \\ ends on line
+    text = re.sub(r"(?<!\\)(\\\\)(\ *\n?)", r"\1\n", text)
+
+    # format tables: align if possible
+    text, placeholders_table = text_to_placeholders(text, [PlaceholderType.tabular])
+    for placeholder in placeholders_table:
+        placeholder.content = _align(placeholder.content)
+    text = text_from_placeholders(text, placeholders_table)
+
     # apply one sentence per line
     text, placeholders_ignore = text_to_placeholders(
         text, [PlaceholderType.math, PlaceholderType.tabular]
     )
     text, placeholders_commands = text_to_placeholders(
-        text,
-        [PlaceholderType.command_like],
-        placeholders_comments=placeholders_comments,
+        text, [PlaceholderType.command_like], placeholders_comments=placeholders_comments
     )
     text = _one_sentence_per_line(text)
     for placeholder in placeholders_commands:
